$TITLE PROGRAM TO CARRY OUT CROSS ENTROPY BALANCING
$OFFSYMLIST OFFSYMXREF OFFUPPER
$oneolcom
$oninline

* Program requires specification of row and column indices
* If square matrix, only one set need be provided,
* and ALIAS statements changed
sets
	i		sam accounts
	ii(i)	all accounts in i except TOTAL
	;

!! these will not be used here but in the CGE
sets AK,CK,FK,IK,K,TAXK,Y,REGION,STATE,AGG,IMPLAN,Z,MAP,ACTCOM;

parameter SAM(*,*),EMPLOY(*,*),TRANSACTION(*,*,*);

$GDXIN unbalsam.gdx
$LOAD SAM
$LOAD i=ALLACCTS
$LOAD ii=ACCTS
!! these will not be used here but in the CGE
$LOAD K,AK,CK,FK,IK,TAXK,Y,REGION,STATE,AGG,IMPLAN,Z,MAP,ACTCOM
$LOAD EMPLOY,TRANSACTION
$GDXOUT

!! not importing these from the SAM since the national aggregation
!! does not export the 28001 account and it is needed for the CGE.
!! Hence, I include it here to always include it in the balanced
!! SAM going to the CGE
set TK /25001, 28001/;

alias (i,j),(ii,jj),(ii,a_ii),(jj,a_jj);

parameters
	SAM0(i,j)		base sam transactions matrix
	T0(i,j)			matrix of sam transactions (flow matrix)
	T1(i,j)			sam transactions adjusted to eliminate negative entries
	Abar0(i,j)		prior sam coefficient matrix
	Abar1(i,j)		prior sam adjusted to eliminate negative coefficients
	Target0(i)		Targets for macro SAM row totals
	epsilon			tolerance to allow zero entries in sam
	;

!! initializing parameters
SAM("TOTAL",jj)		= sum(ii,SAM(ii,jj));
SAM(ii,"TOTAL")		= sum(jj,SAM(ii,jj));
sam0(i,j)			= sam(i,j);

!! divide sam entries by 1000 for better scaling.

scalar scalesam scaling value /1000/;

sam(i,j)				= sam(i,j)/scalesam;
Abar0(ii,jj)$SAM(ii,jj)	= SAM(ii,jj)/SAM("TOTAL",jj);

T0(ii,jj)				= SAM(ii,jj);
T0("TOTAL",jj)			= sum(ii,SAM(ii,jj));
T0(ii,"TOTAL")			= sum(jj,SAM(ii,jj));

epsilon				= 0.00001;

display T0, Abar0;

!! the entropy difference procedure uses logarithms: negative flows in
!! the sam are not good!

set red(i,j) set of negative SAM FLOWS;

parameters
	redsam(i,j)		negative sam values only
	rtot(i)			row total
	ctot(i)			column total
	;

rtot(ii)					= sum(jj,T0(ii,jj));
ctot(jj)					= sum(ii,T0(ii,jj));

red(ii,jj)$(T0(ii,jj) lt 0)	= yes;
redsam(ii,jj)				= 0;
redsam(ii,jj)$red(ii,jj)	= T0(ii,jj);
redsam(jj,ii)$red(ii,jj)	= T0(ii,jj);

!! note that redsam includes each entry twice, in correspoding row
!! and column. So, redsam need only be subtracted from T0.
T1(ii,jj)					= T0(ii,jj) - redsam(ii,jj);
T1("Total",jj)				= sum(ii,T1(ii,jj));
T1(ii,"Total")				= sum(jj,T1(ii,jj));

redsam("total",jj)			= sum(ii,redsam(ii,jj));
redsam(ii,"total")			= sum(jj,redsam(ii,jj));

sam(ii,"total")				= sum(jj,T1(ii,jj));
sam("total",jj)				= sum(ii,T1(ii,jj));

rtot(ii)					= sum(jj,T1(ii,jj));
ctot(jj)					= sum(ii,T1(ii,jj));

Abar1(ii,jj)				= T1(ii,jj)/sam("total",jj);

display "NON-NEGATIVE SAM";
display redsam, T1, Abar0, Abar1, rtot, ctot;

!! define set of elements of sam that can be nonzero. In this case, only
!! elements which are nonzero in initial sam.

set NONZERO(i,j) sam elements that can be nonzero;

NONZERO(ii,jj)$(Abar1(ii,jj)) = yes;

!! initializing parameters after accounting for negative values
!! note that target column sums are being set to average of initial
!! row and column sums. Initial column sums or other values
!! could have been used instead, depending on knowledge of data quality
!! and any other prior information.

target0(ii)		= (sam(ii,"total") + sam("total",ii))/2;

!! variables and "shadow prices" or complementary variables or
!! Lagrange multipliers for all constraint equations
variables
	A(ii,jj)		post sam coefficient matrix
	TSAM(ii,jj)		post matrix of sam transactions
	W(ii)			row sum of sam
	X(ii)			column sum of SAM
	m_SAMEQ(i)		multiplier for row and column sum constraint
	m_SAMMAKE(i,j)	multiplier for make sam flows constraint
	m_ROWSUM(i)		multiplier for row target constraint
	m_COLSUM(j)		multiplier for column target constraint
	;

!! initialize variables
A.L(ii,jj)		= Abar1(ii,jj);
TSAM.L(ii,jj)	= T1(ii,jj);
W.L(ii)			= target0(ii);
X.L(ii)			= target0(ii);

!! core equations and first order conditions (foc)
equations
	SAMEQ(i)			row and column sum constraint
	SAMMAKE(i,j)		make sam flows
	ROWSUM(i)			row target
	COLSUM(j)			column target
	d_A(a_ii,a_jj)		foc wrt the choice variable A
	d_TSAM(a_ii,a_jj)	foc wrt the variable TSAM
	d_W(a_ii)			foc wrt the variable W
	d_X(a_ii)			foc wrt the variable X
	;

!! core equations
SAMEQ(ii)..							W(ii)				=E= X(ii);
SAMMAKE(ii,jj)$nonzero(ii,jj)..		TSAM(ii,jj)			=E= A(ii,jj)*X(jj);
ROWSUM(ii)$(NOT SAMEAS(ii,"RoW"))..	SUM(jj,TSAM(ii,jj))	=E= W(ii);
COLSUM(jj)..						SUM(ii,TSAM(ii,jj))	=E= X(jj);

!! first order conditions for minimizing the objective function

!! equation: foc wrt the choice variable A
d_A(a_ii,a_jj)..
	((log(a(a_ii,a_jj)+epsilon)-log(abar1(a_ii,a_jj)+epsilon))
	$(nonzero(a_ii,a_jj)) + a(a_ii,a_jj)*(1/(a(a_ii,a_jj)+epsilon))
	$(nonzero(a_ii,a_jj)))-
	sum((ii,jj)$(nonzero(ii,jj)),m_sammake(ii,jj)*(-(1$((sameas
	(a_ii,ii) and sameas(a_jj,jj))))*(x(jj))))			=E= 0;

!! equation: foc wrt the variable TSAM
d_TSAM(a_ii,a_jj).. -
	m_colsum(a_jj)-
	m_rowsum(a_ii)$((not sameas(a_ii,"RoW")))-
	m_sammake(a_ii,a_jj)$(nonzero(a_ii,a_jj))			=E= 0;

!! equation: foc wrt the variable W
d_W(a_ii).. -
	m_sameq(a_ii)-
	sum((ii)$((not sameas(ii,"RoW"))),m_rowsum(ii)*(-(1$((sameas
	(a_ii,ii))))))										=E= 0;

!! equation: foc wrt the variable X
d_X(a_ii)..
	sum(jj,m_colsum(jj)*(-(1$((sameas(a_ii,jj))))))-
	sum(ii,m_sameq(ii)*(-(1$((sameas(a_ii,ii))))))-
	sum((ii,jj)$(nonzero(ii,jj)),m_sammake(ii,jj)*(-a(ii,jj)*(1
	$((sameas(a_ii,jj))))))								=E= 0;

!! define model

model SAMENTROP /
	d_A.A
	d_TSAM.TSAM
	d_W.W
	d_X.X
	COLSUM.m_COLSUM
	SAMEQ.m_SAMEQ
	ROWSUM.m_ROWSUM
	SAMMAKE.m_SAMMAKE
	/;

!! defining equation SAMMAKE over non-zero elements of A ($Abar1(ii,jj))
!! guarantees that the zero structure of the original sam is maintained
!! in the estimated sam. Fixing all the zero entires to zero greatly
!! reduces the size of the estimation problem. If it is desired to
!! allow a zero entry to become nonzero in the estimated sam, then
!! the condition $ABAR1(ii,jj) must be replaced with a new set that
!! does not include cells which are currently zero but may be nonzero.

A.LO(ii,jj)$nonzero(ii,jj)			= 0;
A.UP(ii,jj)$nonzero(ii,jj)			= 1;
A.FX(ii,jj)$(NOT nonzero(ii,jj))	= 0;

TSAM.lo(ii,jj)						= 0.0;
TSAM.up(ii,jj)						= +inf;
TSAM.fx(ii,jj)$(NOT nonzero(ii,jj))	= 0;

!! set target column sums, X. if these are not fixed, then the column sum
!! constraint will not be binding.

X.FX(ii)							= TARGET0(ii);

!! solve model
OPTION ITERLIM			= 5000;
OPTION LIMROW			= 0;
OPTION LIMCOL			= 0;
OPTION SOLPRINT			= ON;
SAMENTROP.HOLDFIXED		= 1;
OPTION MCP				= PATHC;

SOLVE SAMENTROP using mcp;

!! parameters for reporting results

parameters
	balsam(i,j)		assigned new balanced sam flows from CE
	NBALSAM(i,j)		balanced sam flows from entrop diff x scalesam
	sem				squared error measure
	percent1(i,j)	percent change of new sam from original sam
	origsam(i,j)	positive unbalanced sam
	posbalan(i,j)	positive balanced sam
	difference(i,j)	difference between original sam and final sam in values
	normentrop		normalized entropy a measure of total uncertainty
	;

balsam(ii,jj)			= TSAM.l(ii,jj);
balsam("total",jj)		= sum(ii,balsam(ii,jj));
balsam(ii,"total") 		= sum(jj,balsam(ii,jj));
NBALSAM(i,j)				= balsam(i,j)*scalesam;
sem						= sum((ii,jj),sqr(A.l(ii,jj) - Abar1(ii,jj))) / SQR(card(ii));
percent1(i,j)$(T1(i,j))	= 100*(balsam(i,j) - T1(i,j)) / T1(i,j);
origsam(i,j)			= T0(i,j) * scalesam;
!!normentrop				= sum((ii,jj)$(Abar1(ii,jj)),A.l(ii,jj)*log(A.l(ii,jj))) / sum((ii,jj)$(Abar1(ii,jj)),Abar1(ii,jj)*log(Abar1(ii,jj)));

!! return negative flows to initial cell position

balsam(ii,jj)			= balsam(ii,jj) + redsam(ii,jj);
balsam(ii,jj)$red(ii,jj) = balsam(ii,jj) - balsam(jj,ii);
balsam(ii,jj)$red(jj,ii) = 0; 
balsam("total",jj)		= sum(ii,balsam(ii,jj));
balsam(ii,"total")		= sum(jj,balsam(ii,jj));
NBALSAM(i,j)			= balsam(i,j)*scalesam;

difference(i,j)			= NBALSAM(i,j) - origsam(i,j);

!! check parameters for balanced sam
parameter 
	rowcoldiff(ii)	differences between row and column sums
	sam_chk			difference between the sum of row and column sums
	diff_chk		summation of the absolute values of the differences between column and row totals
	;
rowcoldiff(ii)	= NBALSAM("total",ii) - NBALSAM(ii,"total");
sam_chk			= sum(jj,NBALSAM("total",jj))-sum(ii,NBALSAM(ii,"total"));
diff_chk		= sum(ii,abs(rowcoldiff(ii)));

display balsam,origsam,NBALSAM,difference,percent1,sem,rowcoldiff,sam_chk,diff_chk; !!normentrop,

execute_unload "balsam.gdx",NBALSAM,K,AK,CK,FK,IK,TAXK,TK,Y,REGION,STATE,AGG,IMPLAN,Z,MAP,ACTCOM,EMPLOY,TRANSACTION;

!! checking the changes for the Real Estate commodity consumption
!!parameter diff(AK),percent(AK);
!!diff(AK) = difference("3360",AK);
!!percent(AK) = percent1("3360",AK);
!!display diff, percent;
*/
