*End-of-line comments
$oneolcom
*In-line comments
$oninline
*Allow empty data sets and parameters
$onempty

SETS
	Y IMPLAN codes for the entire set of activities and commodities
	REGION Regional aggregation as an identification of the SAM
	STATE U.S. States
	AGG(STATE) Arbitrary Regional Aggregation (Follow from IMPLAN)
	K IMPLAN codes for the rows and columns of the IMPLAN SAM
	IMPLAN(K,Y) mapping the aggregated activities and commodities to the entire set of 440 IMPLAN sectors
	Z IMPLAN abbreviations for the rows and columns in the extended SAM
	MAP(K,Z) Mappping set to assign abbreviations to the IMPLAN codes
	AK(K) Activities
	CK(K) Commodities
	FK(K) New Value Added Accounts
	IK(K) Institutions
	TAXK(K) Taxes
	TK(K) Trade Regions
	ACTCOM(AK,CK) One-to-one mapping of activities and commodities
;

PARAMETERS SAM(*,*),EMPLOY(*,AK),TRANSACTION(*,*,*);
ALIAS (K,KK),(Z,ZZ);

$GDXIN balsam.gdx
$LOAD SAM=NBALSAM
$LOAD K,AK,CK,FK,IK,TAXK,TK,Y,REGION,STATE,AGG,IMPLAN,Z,MAP,ACTCOM
$LOAD EMPLOY
$LOAD TRANSACTION
$GDXOUT

!!Since TOTAL is included in the K set, I do not want to use it in the following calculation of
!!percentages or anything like that
SAM("TOTAL",K)	= 0;
SAM(K,"TOTAL") 	= 0;

!!SEPARATING CAPITAL AND LABOR RETURNS FROM PROPRIETARY INCOME			    

!!This is the section where the IMPLAN value-added category of "Proprietary   
!!Income" is partitioned into capital and labor returns. The two old "Employee
!!Compensation" and "Other Property Type Income" accounts are converted into  
!!the new CAPITAL and LABOR accounts. The capital and labor shares of
!!"Proprietary Income" are added to these two new accounts.					

!!Reading the GDX file with the employment set (EMPL) and the percentages (PERC)
$GDXIN PROPRIETORS.gdx
Set EMPL(*);
$LOAD EMPL
Parameter NUMBER(STATE,Y,EMPL) Number of W&S employees and proprietors per state per IMPLAN activity;
$LOAD NUMBER
$GDXIN

	PARAMETER
		NNUMBER(STATE,K,EMPL) New numbers imported and adjusted to conform with the sectorial aggregation
		PROPRIETORS(AK) 	Number of proprietors in the regional aggregation,
		EMPLOYEES(AK)		Number of wage & salary (W&S) employees in the regional aggregation,
		WAGE(AK)			Wage and salary (W&S) employees average annual wage,
		PROPLABOR(AK)		Proprietors labor income,
		PROPCAP(AK)			Proprietors capital income,
		LAB_PERC(AK)		Percentage of labor from total proprietors income,
		CAP_PERC(AK)		Percentage of capital from total proprietors income,
		TOTCAPITAL			Total capital receipts (row sum) from activities,
		TOTLABOR			Total labor receipts (row sum) from activities,
		TOTCOMP				Total "employee compensation" payments (column sum),
		TOTOPTI				Total "other property type income" payments (column sum),
		TOTPROP				Total "proprietors income" payments (column sum),
		PROP_PERC(K)		Percentage of "proprietors income" payments to institutions,
		DIFFCAPITAL			Difference between total capital receipts (row sum) and "other property type income" payments (column sum),
		DIFFLABOR			Difference between total labor receipts (row sum) and "employee compensation" payments (column sum);	
	!!Separating "Proprietary Income" account (row) into CAPITAL and LABOR using 
	!!the percentages of W&S employees and proprietors estimated and imported 
	!!in the GDX file
		LOOP((STATE,AK),NNUMBER(STATE,AK,EMPL) = SUM(Y$IMPLAN(AK,Y),NUMBER(STATE,Y,EMPL)));
		PROPRIETORS(AK) = SUM(STATE$AGG(STATE),NNUMBER(STATE,AK,"PROP"));
		EMPLOYEES(AK)	= SUM(STATE$AGG(STATE),NNUMBER(STATE,AK,"W&S"));
		WAGE(AK)		= (SAM("5001",AK)/EMPLOYEES(AK))$(SAM("5001",AK) gt 0 and EMPLOYEES(AK) gt 0);
		PROPLABOR(AK)	= PROPRIETORS(AK)*WAGE(AK);
		LAB_PERC(AK)	= (PROPLABOR(AK)/ABS(SAM("6001",AK)))$(ABS(SAM("6001",AK)) gt 0);
		LAB_PERC(AK)$(LAB_PERC(AK) GT 1) = 1;
		CAP_PERC(AK)	= 1 - LAB_PERC(AK);
		PROPCAP(AK)		= CAP_PERC(AK)*SAM("6001",AK);
		PROPLABOR(AK)	= LAB_PERC(AK)*SAM("6001",AK);
	!!Deleting the old "Proprietary Income" account from the SAM:
		SAM("6001",K)	= 0;
	!!Defining the new LABOR account (5001)
		SAM("5001",AK)	= PROPLABOR(AK) + SAM("5001",AK);
	!!Defining the new CAPITAL account (7001)
		SAM("7001",AK)	= PROPCAP(AK) + SAM("7001",AK);
		!! Modification to the logging industry only to include land rent payments later on.
		!! All proprietor's income payment is assigned to the capital account
			SAM("5001","16") = SAM("5001","16") - PROPLABOR("16");
			SAM("7001","16") = SAM("7001","16") + PROPLABOR("16");
	!!Adjusting the columns of the new CAPITAL and LABOR accounts to match
	!!account expenditures (column sums) and receipts (row sums)
		TOTCAPITAL		= SUM(K,SAM("7001",K));
		TOTLABOR		= SUM(K,SAM("5001",K));
		TOTCOMP			= SUM(K,SAM(K,"5001")) ;
		TOTPROP			= SUM(K,SAM(K,"6001"));
		TOTOPTI			= SUM(K,SAM(K,"7001"));
		DIFFCAPITAL		= TOTCAPITAL - TOTOPTI;
		DIFFLABOR		= TOTLABOR - TOTCOMP;
		PROP_PERC(K)	= SAM(K,"6001")/TOTPROP;
		SAM(K,"6001")	= 0;
	!!Creating the columns for the new LABOR and CAPITAL accounts
		SAM(K,"5001") 	= SAM(K,"5001") + (PROP_PERC(K)*DIFFLABOR);
		SAM(K,"7001")	= SAM(K,"7001") + (PROP_PERC(K)*DIFFCAPITAL);

!!INCLUDING LAND RENTS                                                       
                                                                           
!!This is the section where the land rents will be included into the extended
!!IMPLAN SAM by Major Land Resource Area (MLRA).                             

!!Reading the LAND.gdx file including the MLRA per state and per activity.
!!STMLRA stands for STATE MLRA since the GDX files separates the MLRAs in
!!different states. LAND contains the "estimated" land rents per MLRA per activity
!!in millions of US$.
$GDXIN LAND.gdx
Set STMLRA(K);
$LOAD STMLRA
Parameter LAND(STATE,STMLRA,K);
Parameter ACRES(STATE,STMLRA,K);
$LOAD LAND
$LOAD ACRES
$GDXIN

	!!There are some IMPLAN activities related to agriculture that use land where 
	!!feedstock for biofuels could potentially be grown. These agricultural activities 
	!!are included in this AGR set as a subset of the activities (IND) coming from the 
	!!LAND.gdx file. Exclude vegetable and melon (3), Fruit (4), Tree nut (5), 
	!!Greenhouse, nursery and floriculture (6), Poultry (13) and All other animal (14). 
		SET AGR(K) Agricultural activities competing for land for biofuels /
			1,2,7,8,9,10,11,12,16/; !!Include the federal government (11001) if CRP is considered
		ALIAS (AGR,AGR1);
	!!Since the ag land payments need to go to the land owners, the HOUSENT set will be used to
	!!divide these payments between households and enterprises.
		SET HOUSENT(K) Institutions that will receive the land payments /
			10001*10009,13001/;
		ALIAS (HOUSENT,HOUSENT1);
	!!Mapping the MLRA per state for each state.
		SET MAP1(STATE,STMLRA) /
			1.MLRA218
            1.MLRA221
            1.MLRA224
            1.MLRA225
            1.MLRA234
            1.MLRA238
            1.MLRA240
            4.MLRA045
            4.MLRA050
            4.MLRA052
            4.MLRA053
            5.MLRA205
            5.MLRA208
            5.MLRA210
            5.MLRA212
            5.MLRA230
            5.MLRA231
            5.MLRA233
            5.MLRA235
            5.MLRA236
            5.MLRA239
            6.MLRA006
            6.MLRA007
            6.MLRA019
            6.MLRA020
            6.MLRA022
            6.MLRA023
            6.MLRA024
            6.MLRA025
            6.MLRA026
            6.MLRA028
            6.MLRA029
            6.MLRA033
            6.MLRA037
            6.MLRA038
            6.MLRA039
            8.MLRA043
            8.MLRA044
            8.MLRA046
            8.MLRA065
            8.MLRA066
            8.MLRA067
            8.MLRA070
            8.MLRA096
            8.MLRA097
            8.MLRA105
            9.MLRA248
            9.MLRA250
            10.MLRA263
            10.MLRA264
            12.MLRA234
            12.MLRA242
            12.MLRA259
            12.MLRA261
            12.MLRA265
            12.MLRA266
            12.MLRA267
            13.MLRA224
            13.MLRA225
            13.MLRA228
            13.MLRA234
            13.MLRA240
            13.MLRA241
            13.MLRA261
            13.MLRA262
            16.MLRA011
            16.MLRA012
            16.MLRA014
            16.MLRA017
            16.MLRA018
            16.MLRA032
            16.MLRA059
            16.MLRA060
            16.MLRA061
            16.MLRA062
            17.MLRA166
            17.MLRA178
            17.MLRA184
            17.MLRA185
            17.MLRA189
            17.MLRA197
            17.MLRA200
            17.MLRA202
            17.MLRA203
            17.MLRA204
            17.MLRA214
            17.MLRA236
            18.MLRA169
            18.MLRA184
            18.MLRA189
            18.MLRA191
            18.MLRA192
            18.MLRA193
            18.MLRA194
            18.MLRA199
            18.MLRA200
            18.MLRA202
            18.MLRA215
            18.MLRA216
            18.MLRA217
            18.MLRA218
            19.MLRA175
            19.MLRA176
            19.MLRA177
            19.MLRA178
            19.MLRA181
            19.MLRA182
            19.MLRA186
            19.MLRA187
            19.MLRA188
            19.MLRA204
            20.MLRA105
            20.MLRA106
            20.MLRA107
            20.MLRA108
            20.MLRA109
            20.MLRA111
            20.MLRA115
            20.MLRA119
            20.MLRA121
            20.MLRA122
            20.MLRA137
            20.MLRA179
            20.MLRA182
            20.MLRA196
            21.MLRA214
            21.MLRA217
            21.MLRA218
            21.MLRA220
            21.MLRA221
            21.MLRA236
            22.MLRA230
            22.MLRA231
            22.MLRA232
            22.MLRA234
            22.MLRA235
            22.MLRA236
            22.MLRA256
            22.MLRA258
            22.MLRA259
            22.MLRA260
            23.MLRA247
            23.MLRA249
            24.MLRA223
            24.MLRA252
            24.MLRA253
            24.MLRA254
            24.MLRA263
            24.MLRA264
            25.MLRA248
            25.MLRA249
            25.MLRA255
            26.MLRA152
            26.MLRA157
            26.MLRA160
            26.MLRA161
            26.MLRA162
            26.MLRA163
            26.MLRA165
            26.MLRA167
            26.MLRA168
            26.MLRA169
            26.MLRA170
            26.MLRA192
            27.MLRA079
            27.MLRA080
            27.MLRA149
            27.MLRA152
            27.MLRA153
            27.MLRA155
            27.MLRA156
            27.MLRA159
            27.MLRA173
            27.MLRA175
            27.MLRA176
            27.MLRA177
            27.MLRA178
            28.MLRA230
            28.MLRA234
            28.MLRA236
            28.MLRA238
            28.MLRA259
            29.MLRA182
            29.MLRA187
            29.MLRA188
            29.MLRA196
            29.MLRA197
            29.MLRA203
            29.MLRA204
            29.MLRA205
            29.MLRA206
            29.MLRA207
            29.MLRA230
            30.MLRA059
            30.MLRA060
            30.MLRA063
            30.MLRA071
            30.MLRA072
            30.MLRA075
            30.MLRA081
            30.MLRA086
            31.MLRA091
            31.MLRA092
            31.MLRA093
            31.MLRA095
            31.MLRA104
            31.MLRA105
            31.MLRA106
            31.MLRA108
            31.MLRA175
            31.MLRA179
            31.MLRA182
            32.MLRA030
            32.MLRA031
            32.MLRA032
            32.MLRA033
            32.MLRA034
            32.MLRA036
            32.MLRA037
            32.MLRA038
            33.MLRA247
            33.MLRA248
            33.MLRA249
            34.MLRA248
            34.MLRA253
            34.MLRA254
            34.MLRA264
            35.MLRA045
            35.MLRA046
            35.MLRA050
            35.MLRA051
            35.MLRA053
            35.MLRA054
            35.MLRA065
            35.MLRA099
            35.MLRA100
            35.MLRA101
            35.MLRA113
            35.MLRA114
            36.MLRA172
            36.MLRA243
            36.MLRA244
            36.MLRA246
            36.MLRA247
            36.MLRA248
            36.MLRA255
            37.MLRA228
            37.MLRA234
            37.MLRA240
            37.MLRA241
            37.MLRA261
            37.MLRA262
            38.MLRA072
            38.MLRA073
            38.MLRA075
            38.MLRA076
            38.MLRA077
            38.MLRA079
            38.MLRA083
            39.MLRA170
            39.MLRA191
            39.MLRA192
            39.MLRA194
            39.MLRA195
            39.MLRA199
            39.MLRA217
            39.MLRA220
            39.MLRA222
            39.MLRA243
            40.MLRA111
            40.MLRA115
            40.MLRA118
            40.MLRA119
            40.MLRA122
            40.MLRA137
            40.MLRA138
            40.MLRA140
            40.MLRA148
            40.MLRA196
            40.MLRA205
            40.MLRA208
            40.MLRA210
            40.MLRA211
            40.MLRA212
            40.MLRA239
            41.MLRA001
            41.MLRA002
            41.MLRA003
            41.MLRA005
            41.MLRA007
            41.MLRA008
            41.MLRA010
            41.MLRA011
            41.MLRA012
            41.MLRA030
            41.MLRA032
            41.MLRA061
            42.MLRA220
            42.MLRA222
            42.MLRA223
            42.MLRA243
            42.MLRA244
            42.MLRA252
            42.MLRA253
            42.MLRA254
            44.MLRA248
            45.MLRA234
            45.MLRA240
            45.MLRA241
            45.MLRA261
            45.MLRA262
            46.MLRA073
            46.MLRA074
            46.MLRA075
            46.MLRA077
            46.MLRA078
            46.MLRA084
            46.MLRA085
            46.MLRA088
            46.MLRA089
            46.MLRA090
            46.MLRA091
            46.MLRA093
            46.MLRA173
            46.MLRA174
            46.MLRA175
            47.MLRA218
            47.MLRA219
            47.MLRA221
            47.MLRA224
            47.MLRA228
            47.MLRA230
            47.MLRA234
            47.MLRA236
            48.MLRA054
            48.MLRA100
            48.MLRA111
            48.MLRA112
            48.MLRA113
            48.MLRA114
            48.MLRA115
            48.MLRA117
            48.MLRA118
            48.MLRA119
            48.MLRA122
            48.MLRA123
            48.MLRA125
            48.MLRA126
            48.MLRA127
            48.MLRA130
            48.MLRA132
            48.MLRA133
            48.MLRA134
            48.MLRA135
            48.MLRA136
            48.MLRA138
            48.MLRA140
            48.MLRA144
            48.MLRA145
            48.MLRA147
            48.MLRA148
            48.MLRA235
            48.MLRA256
            48.MLRA257
            48.MLRA260
            49.MLRA035
            49.MLRA044
            49.MLRA045
            49.MLRA064
            49.MLRA065
            50.MLRA246
            50.MLRA247
            50.MLRA248
            50.MLRA249
            51.MLRA221
            51.MLRA224
            51.MLRA227
            51.MLRA228
            51.MLRA234
            51.MLRA240
            51.MLRA252
            51.MLRA253
            51.MLRA254
            51.MLRA261
            51.MLRA262
            51.MLRA264
            53.MLRA001
            53.MLRA002
            53.MLRA003
            53.MLRA005
            53.MLRA008
            53.MLRA009
            53.MLRA010
            53.MLRA011
            53.MLRA059
            54.MLRA221
            54.MLRA222
            54.MLRA223
            54.MLRA252
            55.MLRA150
            55.MLRA152
            55.MLRA153
            55.MLRA156
            55.MLRA157
            55.MLRA160
            55.MLRA162
            55.MLRA164
            55.MLRA165
            55.MLRA166
            55.MLRA177
            55.MLRA178
            55.MLRA189
            56.MLRA040
            56.MLRA043
            56.MLRA060
            56.MLRA064
            56.MLRA082
            56.MLRA085
            56.MLRA091
            56.MLRA095
			/;
	!!This MLRA set is a subset of the STMLRA including only the states declared in the 
	!!AGG subset of states. The states included in the AGG subset depend on the 
	!!regional aggregation coming from IMPLAN.
		SET MLRA(STMLRA);
		MLRA(STMLRA) = YES$SUM(AGG$MAP1(AGG,STMLRA),1);
	!!This section includes the land rents per MLRA for each activity. The ESTIMATED
	!!land rents are used to obtain a distribution of MLRA land rents per activity. These
	!!shares are then multiplied by the payments from each activity to the IMPLAN
	!!real estate commodity (3360).          
		PARAMETER 
			TOTLAND(AGR) 			Total land rent per activity in the region,
			LANDAGG(STMLRA,AGR)		Aggregated rents over same MLRAs in the regional aggregation in millions of dollars,
			ACRESAGG(STMLRA,AGR)	Aggregated acreage over same MLRAs in the regional aggregation in millions of acres,
			CAPDIFF(AGR)
			MLRAPERC(STMLRA,AGR)	Percentage of land rent for a specific MLRA and activity in the region,
			RENT(STMLRA,AGR)		Land rent by MLRA and agricultural activity (Ready to be included in SAM),
			RENTACRE(STMLRA,AGR)	Land rent per acre by MLRA and activity,
			NONAGR(AGR)				Portion of the real estate commodity income that stays as real estate,
			TOTRENT(STMLRA)			Total land rent by MLRA (row sum total),
			TOTCAPHHENT				Total payments from capital to households and corporation;
	!!Aggregating similar MLRAs in different states included in the regional aggregation
		LANDAGG(STMLRA,AGR) = SUM(STATE$AGG(STATE),LAND(STATE,STMLRA,AGR))/1000000;
		TOTLAND(AGR) = SUM(MLRA,LANDAGG(MLRA,AGR));
		ACRESAGG(STMLRA,AGR) = SUM(STATE$AGG(STATE),ACRES(STATE,STMLRA,AGR))/1000000;
		RENT(STMLRA,AGR) = LANDAGG(STMLRA,AGR);
		LOOP(AGR,
			IF(TOTLAND(AGR) < SAM("3360",AGR),
				NONAGR(AGR) = SAM("3360",AGR) - TOTLAND(AGR);
			ELSE
				CAPDIFF(AGR) = TOTLAND(AGR) - SAM("3360",AGR);
				SAM("7001",AGR) = SAM("7001",AGR) - CAPDIFF(AGR);
			);
		);

	!!Estimates of rents per acre per MLRA for different agricultural activities
		RENTACRE(STMLRA,AGR)$(ACRESAGG(STMLRA,AGR) AND RENT(STMLRA,AGR)) = RENT(STMLRA,AGR) / ACRESAGG(STMLRA,AGR);
	!!Land devoted to CRP is assumed to be demanded by the Federal Govt Non-Defense (11001).
	!!Only the CRP payments recorded for that year for the regional aggregation will 
	!!subtracted from the payment from the government to the Real Estate commodity. The
	!!rest (NOTCRP) will still be paid to the Real State commodity.
		!!PARAMETERS
			!!FEDLAND	Payments from the Federal Government Non-Defense to the Real Estate Commodity
			!!CRP		Recorded total CRP payments for the regional aggregation
			!!NOTCRP	Payments from the Federal Government to the Real Estate Commodity after accounting for CRP payments
			!!;
		!!FEDLAND = SAM("3360","11001");
		!!CRP = TOTLAND("11001")/1000000;
		!!NOTCRP = SAM("3360","11001") - CRP;
		!!RENT(STMLRA,"11001") = LANDAGG(STMLRA,"11001")/1000000;
		!!DISPLAY FEDLAND,CRP,NOTCRP;
	!!Including the land rents into the SAM
		SAM(MLRA,AGR) = RENT(MLRA,AGR);
	!!Deleting the payments from the agricultural activities to the real estate 
	!!intermediate commodity (row 3360 in the SAM)
		SAM("3360",AGR) = 0;
	!!Adding the portion of the payments from the agriculutural activities to the real estate
	!!commodity that was not included in the land rent payments
		SAM("3360",AGR) = NONAGR(AGR);
	!!Recording the non-CRP payments from the federal government
		!!SAM("3360","11001") = NOTCRP;
	!!Creating the columns for the MLRAs and balancing the payments from the MLRAs
	!!to the households and enterprise accounts (HOUSENT set).
	!!Total ag land rent paid to each MLRA
		TOTRENT(STMLRA) = SUM(AGR,RENT(STMLRA,AGR));
	!!Subtracting total ag land rent from the payment to the Real Estate activity 
		SAM("360","3360") = SAM("360","3360") - SUM(AGR,TOTLAND(AGR) - CAPDIFF(AGR));
	!!Since the ag land payments need to go to the land owners, these payments
	!!need to be divided between households and enterprises. Since there is no exact
	!!share information on the amount of land income that goes to each institution,
	!!I've used the distribution of the capital payments to households and enterprises
	!!as a proxy to divide the land payments
		TOTCAPHHENT = SUM(HOUSENT,SAM(HOUSENT,"7001"));
		SAM(HOUSENT,STMLRA) = TOTRENT(STMLRA)*(SAM(HOUSENT,"7001")/TOTCAPHHENT);
	!!Now that all the ag land rent payments from each MLRA have been divided between
	!!households and enterprises, I have to adjust capital payments to households and
	!!enterprises to not double count factor payments to their owners
		SAM(HOUSENT,"7001") = SAM(HOUSENT,"7001") - SUM(STMLRA,SAM(HOUSENT,STMLRA));
	!!Since the ag land rent payments from each MLRA go directly to households and
	!!enterprises, the Real Estate activity does not receive these payments anymore.
	!!Hence, the Real Estate activity's expenditures decrease by the total ag land
	!!rent and is subtracted especifically from the capital (7001) account.
		SAM("7001","360") = SAM("7001","360") - SUM(AGR,TOTLAND(AGR) - CAPDIFF(AGR));	
	!!Estimating mean and maximum rents per acre per activity across MLRAs
		PARAMETER
			AVERAGE(AGR)		Average land rent per acre per activity
			MINIMUM(AGR)		Lowest land rent per acre per activity
			MAXIMUM(AGR)		Highest land rent per acre per activity;
		AVERAGE(AGR)$(SUM(STMLRA$RENTACRE(STMLRA,AGR),1) GT 0) = SUM(STMLRA,RENTACRE(STMLRA,AGR)) / SUM(STMLRA$RENTACRE(STMLRA,AGR),1);
		MINIMUM(AGR) = SMIN(STMLRA,RENTACRE(STMLRA,AGR)); !!minimum is zero for all rents
		MAXIMUM(AGR) = SMAX(STMLRA,RENTACRE(STMLRA,AGR));
		DISPLAY RENTACRE,AVERAGE,MINIMUM,MAXIMUM;

!!TAX ADJUSTMENTS

!!IMPORT DUTIES ADJUSTMENTS
!!The IMPLAN SAM contains the total amount of import duties within the Indirect Business Tax (IBT)
!!payments of the wholesale trade activity. Following conventional SAM structures, these taxes or
!!duties should be reflected as payments from the commodity accounts (columns) to an import tax
!!account (row). Hence, I will obtain the total amount of import duties from the GAMS file imported
!!from IMPLAN under the option "Industry detail SAM Files - GAMS single file". This GAMS file provides
!!a matrix of payment and receipt transactions between institutions including the transaction types.
!!The payments from the IBT account to the different government entities show the totals for sales
!!taxes, property taxes, trade duties, etc. The GTAP import taxes will be helpful to obtain a share
!!of this total import duty figure for the different commodities considered in the aggregation.

!!Importing the duty rates from the TAX.gdx file containing different tax rates from GTAP. Also, including
!!the GAMS single file COMPLETE containing total import duties paid.
ALIAS (Y,YY)
$GDXIN TAX.gdx
PARAMETER dIMPTAX(Y) Import duties data imported from TAX.gdx
$LOAD dIMPTAX=pImportTaxRate
$GDXIN
	
	PARAMETERS 
		pIMPTAX(CK)		Import duties parameters going into SAM.gdx
		TOTIMPTAX		Total import duties
		IMPTAXPAID(CK)	Total import duties paid by commodity
		WHOLETAX(AK)	Import duties paid by activity included as a wholesale tax
		SUMIMPTAXPAID	Summation of total import duties paid by commodity
		PERCIMPTAX(CK)	Percent of total total import duties by commodity
		WHOLESALEIBT	IBT payments from the wholesale industry
		;
	!!Estimating average import duties for the aggregated IMPLAN sectors
	LOOP(CK,pIMPTAX(CK) = SUM(Y$IMPLAN(CK,Y),dIMPTAX(Y))/SUM(Y$IMPLAN(CK,Y),1));	
	!!Total import duties extracted from the GAMS single file
	TOTIMPTAX = TRANSACTION("11001","15018","8001");
	!!Estimating total import taxes paid by commodity
	IMPTAXPAID(CK) = SAM("25001",CK)*pIMPTAX(CK);
	!!Calculating the percentages of import taxes paid by commodity
	SUMIMPTAXPAID = SUM(CK,IMPTAXPAID(CK));
	PERCIMPTAX(CK) = IMPTAXPAID(CK)/SUMIMPTAXPAID;
	!!Using the total import duties figure as a control and multiplying it by the percentages
	SAM("IMPTAX",CK) = PERCIMPTAX(CK)*TOTIMPTAX;
	!!Since we have subtracted total import duties from the production of the wholesale trade commodity,
	!!we need to subtract total import duties from the wholesale trade commodity row in the USE submatrix.
	!!To do this, we will subtract the previously adjusted import taxes paid by commodity from the
	!!wholesale trade commodity row demanded by the different activities. Here is where we will use the
	!!one-to-one activity-to-commodity mapping
	LOOP(CK,WHOLETAX(AK)$ACTCOM(AK,CK) = SAM("3319",AK) - SAM("IMPTAX",CK));
	!!To avoid negative values, if the commodity's import tax paid is greater than the activity's IBT payment
	!!it is assumed that the entire IBT is devoted to import tax. The IBT payment takes the place of the
	!!import taxes paid
	LOOP(AK,SAM("IMPTAX",CK)$(ACTCOM(AK,CK) AND (WHOLETAX(AK) LT 0)) = SAM("3319",AK));
	!!A zero is placed as the IBT payment of the respective activity
	WHOLETAX(AK)$(WHOLETAX(AK) LT 0) = 0;
	!!With this new adjustment, we need to recalculate the total import duties paid
	TOTIMPTAX = SUM(CK,SAM("IMPTAX",CK));
	!!Incorporating the import duties component of the wholesale tax into the USE matrix
	SAM("3319",AK) = WHOLETAX(AK);
	!!Subtracting total import duties from the wholesale trade payments to the IBT account
	WHOLESALEIBT = SAM("8001","319"); !!This will be used later in the sales taxes adjustment
	SAM("8001","319") = SAM("8001","319") - TOTIMPTAX;
	!!Subtracting total import duties from the wholesale trade commodity production in the MAKE submatrix
	SAM("319","3319") = SAM("319","3319") - TOTIMPTAX;
	!!Since we have subtracted a portion of the wholesale trade commodity use by different activities, this
	!!needs to be reflected in the MAKE matrix as well. Hence, we will use the mapping again
	LOOP(AK,SAM(AK,CK)$ACTCOM(AK,CK) = SAM(AK,CK) - SAM("IMPTAX",CK));
	!!Subtracting total import duties from the IBT payments to the federal government
	SAM("11001","8001") = SAM("11001","8001") - TOTIMPTAX;
	!!Adding the payments from the Import Taxes account to the federal government
	SAM("11001","IMPTAX") = TOTIMPTAX;

!!ADJUSTING THE RETAIL AND WHOLESALE INDIRECT BUSINESS TAXES
!!According to Dixon and Rimmer (2002) and Giesecke (2009), taxes are recorded in the
!!column of the industry collecting them, not the institutions producing the commodities on which
!!the taxes are levied. Hence, most taxes appear on the output of the retail and wholesale industries.
!!The IBTs paid by the retail and wholesale industries need to be redistributed to the industries and
!!institutions consuming the commodities on which the taxes are levied. Hence the reduction in the 
!!payments from the retail and wholesale industries to the IBT account will be added to the payments 
!!from the industries and institutions using the wholesale and retail commodities to the IBT account.

!!ADJUSTING RETAIL TAXES
!!According to Dixon and Rimmer (2002), retail taxes account for approximately 28% of the total
!!sales taxes paid by different institutions. The amount of total sales taxes can be obtained
!!from IMPLAN's GAMS single file COMPLETE. By multiplying it by 28% we would be estimating total
!!retail taxes paid and subtract it from the payment from the retail activity to the IBT account.

	PARAMETERS
		TOTSALETAX		Total sales taxes paid
		TOTRETAILTAX	Share of sales taxes entirely assigned to the retail activity
		TOTRETAIL		Total usage of the retail commodity
		ARETAILPERC(AK)	Shares of total retail commodity demanded by each activity
		IRETAILPERC(IK)	Shares of total retail commodity demanded by each institutions	
		ARETAILTAX(AK)	Redistributed part (per activity) of the sales tax collected by the retail industry
		IRETAILTAX(IK)	Redistributed part (per industry) of the sales tax collected by the retail industry
		;
	!!Total sales taxes extracted from the GAMS single file
	TOTSALETAX = TRANSACTION("12001","15020","8001");
	!!Estimating total retail taxes paid as a percent (28%) of total sales taxes paid
	TOTRETAILTAX = TOTSALETAX*0.28;
	!!To distribute total retail taxes paid by activity and institution, shares of total retail 
	!!commodity usage were estimated to reflect the intensity of the usage of the retail commodity by 
	!!activity and institution.
	TOTRETAIL = SUM(AK,SAM("3320",AK)) + SUM(IK,SAM("3320",IK));
	ARETAILPERC(AK) = SAM("3320",AK)/TOTRETAIL;
	IRETAILPERC(IK) = SAM("3320",IK)/TOTRETAIL;
	!!Multiplying the shares by total retail taxes paid
	ARETAILTAX(AK) = ARETAILPERC(AK)*TOTRETAILTAX;
	IRETAILTAX(IK) = IRETAILPERC(IK)*TOTRETAILTAX;
	!!Subtracting total retail taxes from the payment of the retail industry to the IBT account
	SAM("8001","320") = SAM("8001","320") - TOTRETAILTAX;
	!!Since the retail industry column has been modified, its respective row counterpart needs
	!!to be modified as well. Hence, total retail taxes will be subtracted from the production
	!!of the retail commodity by the retail industry in the MAKE submatrix
	SAM("320","3320") = SAM("320","3320") - TOTRETAILTAX;
	!!Since the retail commodity column has been modified, its respective row counterpart needs
	!!to be modified as well. To achieve this, the retail tax per activity and industry previously 
	!!estimated is subtracted from the retail commodity usage by activity and industry and added to 
	!!the IBT payment by each activity and industry
	SAM("3320",AK) = SAM("3320",AK) - ARETAILTAX(AK);
	SAM("3320",IK) = SAM("3320",IK) - IRETAILTAX(IK);
	!!Adding the retail tax to the IBT payments by activity and industry. 
	SAM("8001",AK) = SAM("8001",AK) + ARETAILTAX(AK);
	!!The original IMPLAN SAM only reflects IBT payments from activities, NOT from institutions. 
	!!However, since I'm assigning the sales taxes that were previously paid by the retail sector
	!!to the consuming entities (activities and institutions), I'm adding payments from the consuming 
	!!institutions to the IBT account to the IMPLAN SAM. Let's remember that IBTs include sales taxes. 
	!!Hence, the institutions IBTs are composed entirely of sales taxes.
	SAM("8001",IK) = SAM("8001",IK) + IRETAILTAX(IK);
	
!!ADJUSTING WHOLESALE TAXES
!!The wholesale sector IBT payments have been used to distribute import duties among imported commodities
!!and will be used to distribute the portion of sales taxes among consuming entities (activities and
!!institutions). Since I've already subtracted total import duties paid from the wholesale sector payment
!!to the IBT account, I will use the rest of the IBT payment to redistribute sales taxes among consuming
!!entities.

	PARAMETERS
		TOTWHOLETAX		Share of sales taxes entirely assigned to the wholesale activity
		TOTWHOLE		Total usage of the wholesale commodity
		AWHOLEPERC(AK)	Shares of total wholesale commodity demanded by each activity
		IWHOLEPERC(IK)	Shares of total wholesale commodity demanded by each institutions	
		AWHOLETAX(AK)	Redistributed part (per activity) of the sales tax collected by the wholesale industry
		IWHOLETAX(IK)	Redistributed part (per industry) of the sales tax collected by the wholesale industry
		;
	!!Estimating total wholesale taxes paid as a residual of total wholesale IBT net of total import duties
	TOTWHOLETAX = WHOLESALEIBT - TOTIMPTAX;
	!!To distribute total wholesale taxes paid by activity and institution, shares of total wholesale 
	!!commodity usage were estimated to reflect the intensity of the usage of the wholesale commodity by 
	!!activity and industry.
	TOTWHOLE = SUM(AK,SAM("3319",AK)) + SUM(IK,SAM("3319",IK));
	AWHOLEPERC(AK) = SAM("3319",AK)/TOTWHOLE;
	IWHOLEPERC(IK) = SAM("3319",IK)/TOTWHOLE;
	!!Multiplying the shares by total wholesale taxes paid
	AWHOLETAX(AK) = AWHOLEPERC(AK)*TOTWHOLETAX;
	IWHOLETAX(IK) = IWHOLEPERC(IK)*TOTWHOLETAX;
	!!Subtracting total wholesale taxes from the payment of the wholesale industry to the IBT account
	SAM("8001","319") = SAM("8001","319") - TOTWHOLETAX;
	!!Since the wholesale industry column has been modified, its respective row counterpart needs
	!!to be modified as well. Hence, total wholesale taxes will be subtracted from the production
	!!of the wholesale commodity by the wholesale industry in the MAKE submatrix
	SAM("319","3319") = SAM("319","3319") - TOTWHOLETAX;
	!!Since the wholesale commodity column has been modified, its respective row counterpart needs
	!!to be modified as well. To achieve this, the wholesale tax per activity and industry previously 
	!!estimated is subtracted from the wholesale commodity usage by activity and industry and added to 
	!!the IBT payment by each activity and industry
	SAM("3319",AK) = SAM("3319",AK) - AWHOLETAX(AK);
	SAM("3319",IK) = SAM("3319",IK) - IWHOLETAX(IK);
	!!Adding the wholesale tax to the IBT payments by activity and industry. 
	SAM("8001",AK) = SAM("8001",AK) + AWHOLETAX(AK);
	!!The original IMPLAN SAM only reflects IBT payments from activities, NOT from institutions. 
	!!However, since I'm assigning the sales taxes that were previously paid by the wholesale sector
	!!to the consuming entities (activities and institutions), I'm adding payments from the consuming 
	!!institutions to the IBT account to the IMPLAN SAM. Let's remember that IBTs include sales taxes. 
	!!Hence, the institutions IBTs are composed entirely of sales taxes.
	SAM("8001",IK) = SAM("8001",IK) + IWHOLETAX(IK);

!!INCLUDING AFFORESTATION ACTIVITIES FOR THE CGE (not for the SAM)
$GDXIN AFFOREST.gdx
SET WOOD;
$LOAD WOOD
PARAMETER WOODACRE(STATE,STMLRA,WOOD) Acreage of wood types by MLRAS in millions of acres for every state in the US;
$LOAD WOODACRE
PARAMETER CARBON(STATE,STMLRA,WOOD) Acres necessary to sequester a metric ton of CO2 in a year per MLRA and wood type for every state in the US;
$LOAD CARBON
PARAMETER COST(STATE,STMLRA,WOOD) Per acre costs of site preparation oad afforestation by MLRA and wood type for every state in the US;
$LOAD COST
$GDXIN

	PARAMETERS
		WOODACREAGG(STMLRA,WOOD)		Aggregated acreage of wood types over same MLRAs in the regional aggregation
		WOODWEIGHT(AGG,STMLRA,WOOD)		Weights used to estimate regional averages for costs and yields and based on the acreage of wood types
		COSTREGION(STMLRA,WOOD)			Weighted regional averages of per acre costs of site preparation and afforestation by MLRA and wood type
		CARBONREGION(STMLRA,WOOD)		Weighted regional averages of acres necessary to sequester a metric ton of CO2 in a year by MLRA and wood type
		;
	WOODACREAGG(STMLRA,WOOD)	= SUM(STATE$AGG(STATE),WOODACRE(STATE,STMLRA,WOOD));
	WOODWEIGHT(AGG,STMLRA,WOOD)$WOODACREAGG(STMLRA,WOOD) = WOODACRE(AGG,STMLRA,WOOD) / WOODACREAGG(STMLRA,WOOD);
	COSTREGION(STMLRA,WOOD)		= SUM(AGG,COST(AGG,STMLRA,WOOD)*WOODWEIGHT(AGG,STMLRA,WOOD));
	!!The weights need to be reestimated since there are certain regions for which there are no reported
	!!carbon sequestration rates in Birdsey 1996. The weights will be estimated only for those regions
	!!with reported carbon sequestration.
	WOODACRE(STATE,STMLRA,WOOD)	= WOODACRE(STATE,STMLRA,WOOD)$(CARBON(STATE,STMLRA,WOOD) GT 0);
	WOODACREAGG(STMLRA,WOOD)	= SUM(STATE$AGG(STATE),WOODACRE(STATE,STMLRA,WOOD));
	WOODWEIGHT(AGG,STMLRA,WOOD)$WOODACREAGG(STMLRA,WOOD) = WOODACRE(AGG,STMLRA,WOOD) / WOODACREAGG(STMLRA,WOOD);
	CARBONREGION(STMLRA,WOOD)	= SUM(AGG,CARBON(AGG,STMLRA,WOOD)*WOODWEIGHT(AGG,STMLRA,WOOD));
	SETS 
		AF Wood_MLRA combination afforestation activities for the entire nation /
			MLRA001_HARD
            MLRA002_HARD
            MLRA003_HARD
            MLRA005_HARD
            MLRA006_HARD
            MLRA007_HARD
            MLRA008_HARD
            MLRA010_HARD
            MLRA011_HARD
            MLRA012_HARD
            MLRA014_HARD
            MLRA017_HARD
            MLRA018_HARD
            MLRA019_HARD
            MLRA020_HARD
            MLRA022_HARD
            MLRA023_HARD
            MLRA025_HARD
            MLRA026_HARD
            MLRA028_HARD
            MLRA029_HARD
            MLRA030_HARD
            MLRA031_HARD
            MLRA032_HARD
            MLRA033_HARD
            MLRA035_HARD
            MLRA036_HARD
            MLRA037_HARD
            MLRA038_HARD
            MLRA039_HARD
            MLRA040_HARD
            MLRA043_HARD
            MLRA044_HARD
            MLRA045_HARD
            MLRA046_HARD
            MLRA050_HARD
            MLRA052_HARD
            MLRA054_HARD
            MLRA059_HARD
            MLRA060_HARD
            MLRA061_HARD
            MLRA062_HARD
            MLRA063_HARD
            MLRA064_HARD
            MLRA065_HARD
            MLRA066_HARD
            MLRA067_HARD
            MLRA070_HARD
            MLRA071_HARD
            MLRA072_HARD
            MLRA073_HARD
            MLRA074_HARD
            MLRA075_HARD
            MLRA077_HARD
            MLRA078_HARD
            MLRA079_HARD
            MLRA080_HARD
            MLRA081_HARD
            MLRA082_HARD
            MLRA084_HARD
            MLRA085_HARD
            MLRA086_HARD
            MLRA088_HARD
            MLRA089_HARD
            MLRA090_HARD
            MLRA091_HARD
            MLRA092_HARD
            MLRA093_HARD
            MLRA095_HARD
            MLRA096_HARD
            MLRA097_HARD
            MLRA099_HARD
            MLRA104_HARD
            MLRA105_HARD
            MLRA106_HARD
            MLRA107_HARD
            MLRA108_HARD
            MLRA109_HARD
            MLRA115_HARD
            MLRA119_HARD
            MLRA121_HARD
            MLRA122_HARD
            MLRA137_HARD
            MLRA147_HARD
            MLRA148_HARD
            MLRA149_HARD
            MLRA150_HARD
            MLRA152_HARD
            MLRA153_HARD
            MLRA155_HARD
            MLRA156_HARD
            MLRA157_HARD
            MLRA159_HARD
            MLRA160_HARD
            MLRA161_HARD
            MLRA162_HARD
            MLRA163_HARD
            MLRA164_HARD
            MLRA165_HARD
            MLRA166_HARD
            MLRA167_HARD
            MLRA168_HARD
            MLRA169_HARD
            MLRA170_HARD
            MLRA172_HARD
            MLRA173_HARD
            MLRA174_HARD
            MLRA175_HARD
            MLRA176_HARD
            MLRA177_HARD
            MLRA178_HARD
            MLRA179_HARD
            MLRA182_HARD
            MLRA185_HARD
            MLRA186_HARD
            MLRA187_HARD
            MLRA188_HARD
            MLRA189_HARD
            MLRA191_HARD
            MLRA192_HARD
            MLRA193_HARD
            MLRA194_HARD
            MLRA195_HARD
            MLRA196_HARD
            MLRA197_HARD
            MLRA199_HARD
            MLRA200_HARD
            MLRA202_HARD
            MLRA203_HARD
            MLRA204_HARD
            MLRA205_HARD
            MLRA206_HARD
            MLRA207_HARD
            MLRA208_HARD
            MLRA210_HARD
            MLRA211_HARD
            MLRA212_HARD
            MLRA214_HARD
            MLRA215_HARD
            MLRA216_HARD
            MLRA217_HARD
            MLRA218_HARD
            MLRA219_HARD
            MLRA220_HARD
            MLRA221_HARD
            MLRA222_HARD
            MLRA223_HARD
            MLRA224_HARD
            MLRA225_HARD
            MLRA227_HARD
            MLRA228_HARD
            MLRA230_HARD
            MLRA231_HARD
            MLRA232_HARD
            MLRA233_HARD
            MLRA234_HARD
            MLRA235_HARD
            MLRA236_HARD
            MLRA238_HARD
            MLRA239_HARD
            MLRA240_HARD
            MLRA241_HARD
            MLRA242_HARD
            MLRA243_HARD
            MLRA244_HARD
            MLRA246_HARD
            MLRA247_HARD
            MLRA248_HARD
            MLRA249_HARD
            MLRA250_HARD
            MLRA252_HARD
            MLRA253_HARD
            MLRA254_HARD
            MLRA255_HARD
            MLRA256_HARD
            MLRA258_HARD
            MLRA259_HARD
            MLRA260_HARD
            MLRA261_HARD
            MLRA262_HARD
            MLRA263_HARD
            MLRA264_HARD
            MLRA265_HARD
            MLRA266_HARD
            MLRA267_HARD
            MLRA001_SOFT
            MLRA002_SOFT
            MLRA003_SOFT
            MLRA005_SOFT
            MLRA006_SOFT
            MLRA007_SOFT
            MLRA008_SOFT
            MLRA010_SOFT
            MLRA011_SOFT
            MLRA012_SOFT
            MLRA014_SOFT
            MLRA017_SOFT
            MLRA018_SOFT
            MLRA019_SOFT
            MLRA020_SOFT
            MLRA022_SOFT
            MLRA023_SOFT
            MLRA025_SOFT
            MLRA026_SOFT
            MLRA028_SOFT
            MLRA029_SOFT
            MLRA030_SOFT
            MLRA032_SOFT
            MLRA033_SOFT
            MLRA035_SOFT
            MLRA036_SOFT
            MLRA037_SOFT
            MLRA038_SOFT
            MLRA039_SOFT
            MLRA040_SOFT
            MLRA043_SOFT
            MLRA044_SOFT
            MLRA045_SOFT
            MLRA046_SOFT
            MLRA050_SOFT
            MLRA051_SOFT
            MLRA052_SOFT
            MLRA053_SOFT
            MLRA054_SOFT
            MLRA059_SOFT
            MLRA060_SOFT
            MLRA061_SOFT
            MLRA062_SOFT
            MLRA063_SOFT
            MLRA064_SOFT
            MLRA065_SOFT
            MLRA066_SOFT
            MLRA067_SOFT
            MLRA070_SOFT
            MLRA071_SOFT
            MLRA074_SOFT
            MLRA075_SOFT
            MLRA078_SOFT
            MLRA079_SOFT
            MLRA080_SOFT
            MLRA081_SOFT
            MLRA082_SOFT
            MLRA084_SOFT
            MLRA085_SOFT
            MLRA086_SOFT
            MLRA088_SOFT
            MLRA090_SOFT
            MLRA091_SOFT
            MLRA092_SOFT
            MLRA093_SOFT
            MLRA095_SOFT
            MLRA097_SOFT
            MLRA099_SOFT
            MLRA101_SOFT
            MLRA104_SOFT
            MLRA105_SOFT
            MLRA106_SOFT
            MLRA107_SOFT
            MLRA108_SOFT
            MLRA109_SOFT
            MLRA119_SOFT
            MLRA121_SOFT
            MLRA147_SOFT
            MLRA148_SOFT
            MLRA149_SOFT
            MLRA150_SOFT
            MLRA152_SOFT
            MLRA153_SOFT
            MLRA155_SOFT
            MLRA156_SOFT
            MLRA157_SOFT
            MLRA159_SOFT
            MLRA160_SOFT
            MLRA161_SOFT
            MLRA162_SOFT
            MLRA163_SOFT
            MLRA164_SOFT
            MLRA165_SOFT
            MLRA166_SOFT
            MLRA167_SOFT
            MLRA168_SOFT
            MLRA169_SOFT
            MLRA170_SOFT
            MLRA172_SOFT
            MLRA173_SOFT
            MLRA175_SOFT
            MLRA176_SOFT
            MLRA177_SOFT
            MLRA178_SOFT
            MLRA179_SOFT
            MLRA182_SOFT
            MLRA185_SOFT
            MLRA186_SOFT
            MLRA187_SOFT
            MLRA188_SOFT
            MLRA189_SOFT
            MLRA191_SOFT
            MLRA192_SOFT
            MLRA193_SOFT
            MLRA194_SOFT
            MLRA195_SOFT
            MLRA196_SOFT
            MLRA197_SOFT
            MLRA199_SOFT
            MLRA200_SOFT
            MLRA202_SOFT
            MLRA203_SOFT
            MLRA204_SOFT
            MLRA205_SOFT
            MLRA206_SOFT
            MLRA207_SOFT
            MLRA208_SOFT
            MLRA210_SOFT
            MLRA211_SOFT
            MLRA212_SOFT
            MLRA214_SOFT
            MLRA215_SOFT
            MLRA216_SOFT
            MLRA217_SOFT
            MLRA218_SOFT
            MLRA219_SOFT
            MLRA220_SOFT
            MLRA221_SOFT
            MLRA222_SOFT
            MLRA223_SOFT
            MLRA224_SOFT
            MLRA225_SOFT
            MLRA227_SOFT
            MLRA228_SOFT
            MLRA230_SOFT
            MLRA231_SOFT
            MLRA232_SOFT
            MLRA233_SOFT
            MLRA234_SOFT
            MLRA235_SOFT
            MLRA236_SOFT
            MLRA238_SOFT
            MLRA239_SOFT
            MLRA240_SOFT
            MLRA241_SOFT
            MLRA242_SOFT
            MLRA243_SOFT
            MLRA244_SOFT
            MLRA246_SOFT
            MLRA247_SOFT
            MLRA248_SOFT
            MLRA249_SOFT
            MLRA250_SOFT
            MLRA252_SOFT
            MLRA253_SOFT
            MLRA254_SOFT
            MLRA255_SOFT
            MLRA256_SOFT
            MLRA258_SOFT
            MLRA259_SOFT
            MLRA260_SOFT
            MLRA261_SOFT
            MLRA262_SOFT
            MLRA263_SOFT
            MLRA264_SOFT
            MLRA265_SOFT
            MLRA266_SOFT
            MLRA267_SOFT
		/
		AFMAP(AF,STMLRA,WOOD) Map from afforestation activity to MLRA and wood type /	
			MLRA001_HARD.MLRA001.HARD
            MLRA002_HARD.MLRA002.HARD
            MLRA003_HARD.MLRA003.HARD
            MLRA005_HARD.MLRA005.HARD
            MLRA006_HARD.MLRA006.HARD
            MLRA007_HARD.MLRA007.HARD
            MLRA008_HARD.MLRA008.HARD
            MLRA010_HARD.MLRA010.HARD
            MLRA011_HARD.MLRA011.HARD
            MLRA012_HARD.MLRA012.HARD
            MLRA014_HARD.MLRA014.HARD
            MLRA017_HARD.MLRA017.HARD
            MLRA018_HARD.MLRA018.HARD
            MLRA019_HARD.MLRA019.HARD
            MLRA020_HARD.MLRA020.HARD
            MLRA022_HARD.MLRA022.HARD
            MLRA023_HARD.MLRA023.HARD
            MLRA025_HARD.MLRA025.HARD
            MLRA026_HARD.MLRA026.HARD
            MLRA028_HARD.MLRA028.HARD
            MLRA029_HARD.MLRA029.HARD
            MLRA030_HARD.MLRA030.HARD
            MLRA031_HARD.MLRA031.HARD
            MLRA032_HARD.MLRA032.HARD
            MLRA033_HARD.MLRA033.HARD
            MLRA035_HARD.MLRA035.HARD
            MLRA036_HARD.MLRA036.HARD
            MLRA037_HARD.MLRA037.HARD
            MLRA038_HARD.MLRA038.HARD
            MLRA039_HARD.MLRA039.HARD
            MLRA040_HARD.MLRA040.HARD
            MLRA043_HARD.MLRA043.HARD
            MLRA044_HARD.MLRA044.HARD
            MLRA045_HARD.MLRA045.HARD
            MLRA046_HARD.MLRA046.HARD
            MLRA050_HARD.MLRA050.HARD
            MLRA052_HARD.MLRA052.HARD
            MLRA054_HARD.MLRA054.HARD
            MLRA059_HARD.MLRA059.HARD
            MLRA060_HARD.MLRA060.HARD
            MLRA061_HARD.MLRA061.HARD
            MLRA062_HARD.MLRA062.HARD
            MLRA063_HARD.MLRA063.HARD
            MLRA064_HARD.MLRA064.HARD
            MLRA065_HARD.MLRA065.HARD
            MLRA066_HARD.MLRA066.HARD
            MLRA067_HARD.MLRA067.HARD
            MLRA070_HARD.MLRA070.HARD
            MLRA071_HARD.MLRA071.HARD
            MLRA072_HARD.MLRA072.HARD
            MLRA073_HARD.MLRA073.HARD
            MLRA074_HARD.MLRA074.HARD
            MLRA075_HARD.MLRA075.HARD
            MLRA077_HARD.MLRA077.HARD
            MLRA078_HARD.MLRA078.HARD
            MLRA079_HARD.MLRA079.HARD
            MLRA080_HARD.MLRA080.HARD
            MLRA081_HARD.MLRA081.HARD
            MLRA082_HARD.MLRA082.HARD
            MLRA084_HARD.MLRA084.HARD
            MLRA085_HARD.MLRA085.HARD
            MLRA086_HARD.MLRA086.HARD
            MLRA088_HARD.MLRA088.HARD
            MLRA089_HARD.MLRA089.HARD
            MLRA090_HARD.MLRA090.HARD
            MLRA091_HARD.MLRA091.HARD
            MLRA092_HARD.MLRA092.HARD
            MLRA093_HARD.MLRA093.HARD
            MLRA095_HARD.MLRA095.HARD
            MLRA096_HARD.MLRA096.HARD
            MLRA097_HARD.MLRA097.HARD
            MLRA099_HARD.MLRA099.HARD
            MLRA104_HARD.MLRA104.HARD
            MLRA105_HARD.MLRA105.HARD
            MLRA106_HARD.MLRA106.HARD
            MLRA107_HARD.MLRA107.HARD
            MLRA108_HARD.MLRA108.HARD
            MLRA109_HARD.MLRA109.HARD
            MLRA115_HARD.MLRA115.HARD
            MLRA119_HARD.MLRA119.HARD
            MLRA121_HARD.MLRA121.HARD
            MLRA122_HARD.MLRA122.HARD
            MLRA137_HARD.MLRA137.HARD
            MLRA147_HARD.MLRA147.HARD
            MLRA148_HARD.MLRA148.HARD
            MLRA149_HARD.MLRA149.HARD
            MLRA150_HARD.MLRA150.HARD
            MLRA152_HARD.MLRA152.HARD
            MLRA153_HARD.MLRA153.HARD
            MLRA155_HARD.MLRA155.HARD
            MLRA156_HARD.MLRA156.HARD
            MLRA157_HARD.MLRA157.HARD
            MLRA159_HARD.MLRA159.HARD
            MLRA160_HARD.MLRA160.HARD
            MLRA161_HARD.MLRA161.HARD
            MLRA162_HARD.MLRA162.HARD
            MLRA163_HARD.MLRA163.HARD
            MLRA164_HARD.MLRA164.HARD
            MLRA165_HARD.MLRA165.HARD
            MLRA166_HARD.MLRA166.HARD
            MLRA167_HARD.MLRA167.HARD
            MLRA168_HARD.MLRA168.HARD
            MLRA169_HARD.MLRA169.HARD
            MLRA170_HARD.MLRA170.HARD
            MLRA172_HARD.MLRA172.HARD
            MLRA173_HARD.MLRA173.HARD
            MLRA174_HARD.MLRA174.HARD
            MLRA175_HARD.MLRA175.HARD
            MLRA176_HARD.MLRA176.HARD
            MLRA177_HARD.MLRA177.HARD
            MLRA178_HARD.MLRA178.HARD
            MLRA179_HARD.MLRA179.HARD
            MLRA182_HARD.MLRA182.HARD
            MLRA185_HARD.MLRA185.HARD
            MLRA186_HARD.MLRA186.HARD
            MLRA187_HARD.MLRA187.HARD
            MLRA188_HARD.MLRA188.HARD
            MLRA189_HARD.MLRA189.HARD
            MLRA191_HARD.MLRA191.HARD
            MLRA192_HARD.MLRA192.HARD
            MLRA193_HARD.MLRA193.HARD
            MLRA194_HARD.MLRA194.HARD
            MLRA195_HARD.MLRA195.HARD
            MLRA196_HARD.MLRA196.HARD
            MLRA197_HARD.MLRA197.HARD
            MLRA199_HARD.MLRA199.HARD
            MLRA200_HARD.MLRA200.HARD
            MLRA202_HARD.MLRA202.HARD
            MLRA203_HARD.MLRA203.HARD
            MLRA204_HARD.MLRA204.HARD
            MLRA205_HARD.MLRA205.HARD
            MLRA206_HARD.MLRA206.HARD
            MLRA207_HARD.MLRA207.HARD
            MLRA208_HARD.MLRA208.HARD
            MLRA210_HARD.MLRA210.HARD
            MLRA211_HARD.MLRA211.HARD
            MLRA212_HARD.MLRA212.HARD
            MLRA214_HARD.MLRA214.HARD
            MLRA215_HARD.MLRA215.HARD
            MLRA216_HARD.MLRA216.HARD
            MLRA217_HARD.MLRA217.HARD
            MLRA218_HARD.MLRA218.HARD
            MLRA219_HARD.MLRA219.HARD
            MLRA220_HARD.MLRA220.HARD
            MLRA221_HARD.MLRA221.HARD
            MLRA222_HARD.MLRA222.HARD
            MLRA223_HARD.MLRA223.HARD
            MLRA224_HARD.MLRA224.HARD
            MLRA225_HARD.MLRA225.HARD
            MLRA227_HARD.MLRA227.HARD
            MLRA228_HARD.MLRA228.HARD
            MLRA230_HARD.MLRA230.HARD
            MLRA231_HARD.MLRA231.HARD
            MLRA232_HARD.MLRA232.HARD
            MLRA233_HARD.MLRA233.HARD
            MLRA234_HARD.MLRA234.HARD
            MLRA235_HARD.MLRA235.HARD
            MLRA236_HARD.MLRA236.HARD
            MLRA238_HARD.MLRA238.HARD
            MLRA239_HARD.MLRA239.HARD
            MLRA240_HARD.MLRA240.HARD
            MLRA241_HARD.MLRA241.HARD
            MLRA242_HARD.MLRA242.HARD
            MLRA243_HARD.MLRA243.HARD
            MLRA244_HARD.MLRA244.HARD
            MLRA246_HARD.MLRA246.HARD
            MLRA247_HARD.MLRA247.HARD
            MLRA248_HARD.MLRA248.HARD
            MLRA249_HARD.MLRA249.HARD
            MLRA250_HARD.MLRA250.HARD
            MLRA252_HARD.MLRA252.HARD
            MLRA253_HARD.MLRA253.HARD
            MLRA254_HARD.MLRA254.HARD
            MLRA255_HARD.MLRA255.HARD
            MLRA256_HARD.MLRA256.HARD
            MLRA258_HARD.MLRA258.HARD
            MLRA259_HARD.MLRA259.HARD
            MLRA260_HARD.MLRA260.HARD
            MLRA261_HARD.MLRA261.HARD
            MLRA262_HARD.MLRA262.HARD
            MLRA263_HARD.MLRA263.HARD
            MLRA264_HARD.MLRA264.HARD
            MLRA265_HARD.MLRA265.HARD
            MLRA266_HARD.MLRA266.HARD
            MLRA267_HARD.MLRA267.HARD
            MLRA001_SOFT.MLRA001.SOFT
            MLRA002_SOFT.MLRA002.SOFT
            MLRA003_SOFT.MLRA003.SOFT
            MLRA005_SOFT.MLRA005.SOFT
            MLRA006_SOFT.MLRA006.SOFT
            MLRA007_SOFT.MLRA007.SOFT
            MLRA008_SOFT.MLRA008.SOFT
            MLRA010_SOFT.MLRA010.SOFT
            MLRA011_SOFT.MLRA011.SOFT
            MLRA012_SOFT.MLRA012.SOFT
            MLRA014_SOFT.MLRA014.SOFT
            MLRA017_SOFT.MLRA017.SOFT
            MLRA018_SOFT.MLRA018.SOFT
            MLRA019_SOFT.MLRA019.SOFT
            MLRA020_SOFT.MLRA020.SOFT
            MLRA022_SOFT.MLRA022.SOFT
            MLRA023_SOFT.MLRA023.SOFT
            MLRA025_SOFT.MLRA025.SOFT
            MLRA026_SOFT.MLRA026.SOFT
            MLRA028_SOFT.MLRA028.SOFT
            MLRA029_SOFT.MLRA029.SOFT
            MLRA030_SOFT.MLRA030.SOFT
            MLRA032_SOFT.MLRA032.SOFT
            MLRA033_SOFT.MLRA033.SOFT
            MLRA035_SOFT.MLRA035.SOFT
            MLRA036_SOFT.MLRA036.SOFT
            MLRA037_SOFT.MLRA037.SOFT
            MLRA038_SOFT.MLRA038.SOFT
            MLRA039_SOFT.MLRA039.SOFT
            MLRA040_SOFT.MLRA040.SOFT
            MLRA043_SOFT.MLRA043.SOFT
            MLRA044_SOFT.MLRA044.SOFT
            MLRA045_SOFT.MLRA045.SOFT
            MLRA046_SOFT.MLRA046.SOFT
            MLRA050_SOFT.MLRA050.SOFT
            MLRA051_SOFT.MLRA051.SOFT
            MLRA052_SOFT.MLRA052.SOFT
            MLRA053_SOFT.MLRA053.SOFT
            MLRA054_SOFT.MLRA054.SOFT
            MLRA059_SOFT.MLRA059.SOFT
            MLRA060_SOFT.MLRA060.SOFT
            MLRA061_SOFT.MLRA061.SOFT
            MLRA062_SOFT.MLRA062.SOFT
            MLRA063_SOFT.MLRA063.SOFT
            MLRA064_SOFT.MLRA064.SOFT
            MLRA065_SOFT.MLRA065.SOFT
            MLRA066_SOFT.MLRA066.SOFT
            MLRA067_SOFT.MLRA067.SOFT
            MLRA070_SOFT.MLRA070.SOFT
            MLRA071_SOFT.MLRA071.SOFT
            MLRA074_SOFT.MLRA074.SOFT
            MLRA075_SOFT.MLRA075.SOFT
            MLRA078_SOFT.MLRA078.SOFT
            MLRA079_SOFT.MLRA079.SOFT
            MLRA080_SOFT.MLRA080.SOFT
            MLRA081_SOFT.MLRA081.SOFT
            MLRA082_SOFT.MLRA082.SOFT
            MLRA084_SOFT.MLRA084.SOFT
            MLRA085_SOFT.MLRA085.SOFT
            MLRA086_SOFT.MLRA086.SOFT
            MLRA088_SOFT.MLRA088.SOFT
            MLRA090_SOFT.MLRA090.SOFT
            MLRA091_SOFT.MLRA091.SOFT
            MLRA092_SOFT.MLRA092.SOFT
            MLRA093_SOFT.MLRA093.SOFT
            MLRA095_SOFT.MLRA095.SOFT
            MLRA097_SOFT.MLRA097.SOFT
            MLRA099_SOFT.MLRA099.SOFT
            MLRA101_SOFT.MLRA101.SOFT
            MLRA104_SOFT.MLRA104.SOFT
            MLRA105_SOFT.MLRA105.SOFT
            MLRA106_SOFT.MLRA106.SOFT
            MLRA107_SOFT.MLRA107.SOFT
            MLRA108_SOFT.MLRA108.SOFT
            MLRA109_SOFT.MLRA109.SOFT
            MLRA119_SOFT.MLRA119.SOFT
            MLRA121_SOFT.MLRA121.SOFT
            MLRA147_SOFT.MLRA147.SOFT
            MLRA148_SOFT.MLRA148.SOFT
            MLRA149_SOFT.MLRA149.SOFT
            MLRA150_SOFT.MLRA150.SOFT
            MLRA152_SOFT.MLRA152.SOFT
            MLRA153_SOFT.MLRA153.SOFT
            MLRA155_SOFT.MLRA155.SOFT
            MLRA156_SOFT.MLRA156.SOFT
            MLRA157_SOFT.MLRA157.SOFT
            MLRA159_SOFT.MLRA159.SOFT
            MLRA160_SOFT.MLRA160.SOFT
            MLRA161_SOFT.MLRA161.SOFT
            MLRA162_SOFT.MLRA162.SOFT
            MLRA163_SOFT.MLRA163.SOFT
            MLRA164_SOFT.MLRA164.SOFT
            MLRA165_SOFT.MLRA165.SOFT
            MLRA166_SOFT.MLRA166.SOFT
            MLRA167_SOFT.MLRA167.SOFT
            MLRA168_SOFT.MLRA168.SOFT
            MLRA169_SOFT.MLRA169.SOFT
            MLRA170_SOFT.MLRA170.SOFT
            MLRA172_SOFT.MLRA172.SOFT
            MLRA173_SOFT.MLRA173.SOFT
            MLRA175_SOFT.MLRA175.SOFT
            MLRA176_SOFT.MLRA176.SOFT
            MLRA177_SOFT.MLRA177.SOFT
            MLRA178_SOFT.MLRA178.SOFT
            MLRA179_SOFT.MLRA179.SOFT
            MLRA182_SOFT.MLRA182.SOFT
            MLRA185_SOFT.MLRA185.SOFT
            MLRA186_SOFT.MLRA186.SOFT
            MLRA187_SOFT.MLRA187.SOFT
            MLRA188_SOFT.MLRA188.SOFT
            MLRA189_SOFT.MLRA189.SOFT
            MLRA191_SOFT.MLRA191.SOFT
            MLRA192_SOFT.MLRA192.SOFT
            MLRA193_SOFT.MLRA193.SOFT
            MLRA194_SOFT.MLRA194.SOFT
            MLRA195_SOFT.MLRA195.SOFT
            MLRA196_SOFT.MLRA196.SOFT
            MLRA197_SOFT.MLRA197.SOFT
            MLRA199_SOFT.MLRA199.SOFT
            MLRA200_SOFT.MLRA200.SOFT
            MLRA202_SOFT.MLRA202.SOFT
            MLRA203_SOFT.MLRA203.SOFT
            MLRA204_SOFT.MLRA204.SOFT
            MLRA205_SOFT.MLRA205.SOFT
            MLRA206_SOFT.MLRA206.SOFT
            MLRA207_SOFT.MLRA207.SOFT
            MLRA208_SOFT.MLRA208.SOFT
            MLRA210_SOFT.MLRA210.SOFT
            MLRA211_SOFT.MLRA211.SOFT
            MLRA212_SOFT.MLRA212.SOFT
            MLRA214_SOFT.MLRA214.SOFT
            MLRA215_SOFT.MLRA215.SOFT
            MLRA216_SOFT.MLRA216.SOFT
            MLRA217_SOFT.MLRA217.SOFT
            MLRA218_SOFT.MLRA218.SOFT
            MLRA219_SOFT.MLRA219.SOFT
            MLRA220_SOFT.MLRA220.SOFT
            MLRA221_SOFT.MLRA221.SOFT
            MLRA222_SOFT.MLRA222.SOFT
            MLRA223_SOFT.MLRA223.SOFT
            MLRA224_SOFT.MLRA224.SOFT
            MLRA225_SOFT.MLRA225.SOFT
            MLRA227_SOFT.MLRA227.SOFT
            MLRA228_SOFT.MLRA228.SOFT
            MLRA230_SOFT.MLRA230.SOFT
            MLRA231_SOFT.MLRA231.SOFT
            MLRA232_SOFT.MLRA232.SOFT
            MLRA233_SOFT.MLRA233.SOFT
            MLRA234_SOFT.MLRA234.SOFT
            MLRA235_SOFT.MLRA235.SOFT
            MLRA236_SOFT.MLRA236.SOFT
            MLRA238_SOFT.MLRA238.SOFT
            MLRA239_SOFT.MLRA239.SOFT
            MLRA240_SOFT.MLRA240.SOFT
            MLRA241_SOFT.MLRA241.SOFT
            MLRA242_SOFT.MLRA242.SOFT
            MLRA243_SOFT.MLRA243.SOFT
            MLRA244_SOFT.MLRA244.SOFT
            MLRA246_SOFT.MLRA246.SOFT
            MLRA247_SOFT.MLRA247.SOFT
            MLRA248_SOFT.MLRA248.SOFT
            MLRA249_SOFT.MLRA249.SOFT
            MLRA250_SOFT.MLRA250.SOFT
            MLRA252_SOFT.MLRA252.SOFT
            MLRA253_SOFT.MLRA253.SOFT
            MLRA254_SOFT.MLRA254.SOFT
            MLRA255_SOFT.MLRA255.SOFT
            MLRA256_SOFT.MLRA256.SOFT
            MLRA258_SOFT.MLRA258.SOFT
            MLRA259_SOFT.MLRA259.SOFT
            MLRA260_SOFT.MLRA260.SOFT
            MLRA261_SOFT.MLRA261.SOFT
            MLRA262_SOFT.MLRA262.SOFT
            MLRA263_SOFT.MLRA263.SOFT
            MLRA264_SOFT.MLRA264.SOFT
            MLRA265_SOFT.MLRA265.SOFT
            MLRA266_SOFT.MLRA266.SOFT
            MLRA267_SOFT.MLRA267.SOFT
		/
		AFF(AF) Wood_MLRA combination afforestation activites for the regional aggregation;
	!!LOOP((STMLRA,WOOD),AFF(AF)$AFMAP(AF,STMLRA,WOOD) = YES$((WOODACREAGG(STMLRA,WOOD) GT 0) AND (CARBONREGION(STMLRA,WOOD) GT 0) AND (SAM(STMLRA,"16") GE 0.01)));
	LOOP((STMLRA,WOOD),AFF(AF)$AFMAP(AF,STMLRA,WOOD) = YES$((WOODACREAGG(STMLRA,WOOD) AND CARBONREGION(STMLRA,WOOD)) GT 0));

!!ASSEMBLING THE EXTENDED SAM:

!!Structure of the extended SAM
!!  			A		C		F		MLRA	INST	TAX		T(RoW)	T(RoUS)
!!  			1		2		3		4		5		6		7		8	   
!!A			1			MAKE
!!C			2	USE								IUSE			CEXPRT	CEXPRT
!!F			3	VAD								SALETAX			FEXPRT	FEXPRT
!!MLRA		4	LD
!!INST		5			IMAKE	FS		LS		TRNSFR	TAX		INTRNS	INTRNS 
!!TAX		6			IMPTAX
!!T(RoW)	7			CIMPRT	FIMPRTF			OUTTRNS			TRNSHP	TRNSHP
!!T(RoUS)	8			CIMPRT	FIMPRTD			OUTTRNS			TRNSHP	TRNSHP

	!!These totals will be included in the creation of the conditional subsets below.
	!!They are used to exclude empty accounts.
	SAM("TOTAL",K)	= 0;
	SAM("TOTAL",K)	= SAM("TOTAL",K) + SUM(KK,SAM(KK,K));

	SET AZ(Z),CZ(Z),FZ(Z),IZ(Z),TZ(Z),MLRAZ(Z),AGRZ(Z),HOUSENTZ(Z),TAXZ(Z);

	AZ(Z) = YES$SUM(AK$(MAP(AK,Z) AND (SAM("TOTAL",AK) NE 0)),1);
	CZ(Z) = YES$SUM(CK$(MAP(CK,Z) AND (SAM("TOTAL",CK) NE 0)),1);
	FZ(Z) = YES$SUM(FK$(MAP(FK,Z) AND (SAM("TOTAL",FK) NE 0)),1);
	IZ(Z) = YES$SUM(IK$(MAP(IK,Z) AND (SAM("TOTAL",IK) NE 0)),1);
	TZ(Z) = YES$SUM(TK$MAP(TK,Z),1);
	!!TZ(Z) = YES$SUM(TK$(MAP(TK,Z) AND (SAM("TOTAL",TK) NE 0)),1);
	MLRAZ(Z) = YES$SUM(MLRA$(MAP(MLRA,Z) AND (SAM("TOTAL",MLRA) NE 0)),1);
	AGRZ(Z) = YES$SUM(AGR$(MAP(AGR,Z) AND (SAM("TOTAL",AGR) NE 0)),1);
	HOUSENTZ(Z) = YES$SUM(HOUSENT$(MAP(HOUSENT,Z) AND (SAM("TOTAL",HOUSENT) NE 0)),1);
	TAXZ(Z) = YES$SUM(TAXK$(MAP(TAXK,Z) AND (SAM("TOTAL",TAXK) NE 0)),1);
	SET	TOTAL(Z) /TOTAL/;
	
	PARAMETERS
		NSAM(Z,ZZ)			New extended SAM including detailed trade data
		LABOR(Z)			Employment data by aggegated activity
		ACREAGE(Z,ZZ)		Acreage data by MLRA and agricultural activity in millions of acres
		ACRERENT(Z,ZZ)		Rents per acre data by aggregated agricultural activity in dollars per acre
		;
	
	!!Separating the different submatrices included in the BASIC SAM and defining
	!!the submatrices for the satellite matrices
		ALIAS (IK,IIK),(TK,TTK),(IZ,IIZ),(TZ,TTZ);

	!!Commodity and factor supply and demand
		!!Commodity production by activities (MAKE submatrix):
		NSAM(AZ,CZ)		= SUM((AK,CK)$(SAM(AK,CK)$(MAP(AK,AZ)*MAP(CK,CZ))),SAM(AK,CK));
	
		!!Commodity production by institutions (IMAKE submatrix):
		NSAM(IZ,CZ)     = SUM((IK,CK)$(SAM(IK,CK)$(MAP(IK,IZ)*MAP(CK,CZ))),SAM(IK,CK));
	
		!!Intermediate demand of commodities by activities (USE submatrix):
		NSAM(CZ,AZ)     = SUM((CK,AK)$(SAM(CK,AK)$(MAP(CK,CZ)*MAP(AK,AZ))),SAM(CK,AK));
	
		!!Final demand of commodities by institutions (IUSE submatrix):
		NSAM(CZ,IZ)     = SUM((CK,IK)$(SAM(CK,IK)$(MAP(CK,CZ)*MAP(IK,IZ))),SAM(CK,IK));
	
		!!Value added (including IBTs) by activities (VAD submatrix):
		NSAM(FZ,AZ)     = SUM((FK,AK)$(SAM(FK,AK)$(MAP(FK,FZ)*MAP(AK,AZ))),SAM(FK,AK));

		!!Indirect business taxes (sales taxes) paid by institutions (SALETAX submatrix):
		NSAM(FZ,IZ)     = SUM((FK,IK)$(SAM(FK,IK)$(MAP(FK,FZ)*MAP(IK,IZ))),SAM(FK,IK));
	
		!!Factor supply by institutions (FS submatrix):
		NSAM(IZ,FZ)     = SUM((IK,FK)$(SAM(IK,FK)$(MAP(IK,IZ)*MAP(FK,FZ))),SAM(IK,FK));
	
		!!Infra-institutional transfers (TRNSFR submatrix):
		NSAM(IZ,IIZ) 	= SUM((IK,IIK)$(SAM(IK,IIK)$(MAP(IK,IZ)*MAP(IIK,IIZ))),SAM(IK,IIK));
	
		!!Agricultural land supply by households and enterprises (LS submatrix):
		NSAM(HOUSENTZ,MLRAZ) 	= SUM((HOUSENT,MLRA)$(SAM(HOUSENT,MLRA)$(MAP(HOUSENT,HOUSENTZ)*MAP(MLRA,MLRAZ))),SAM(HOUSENT,MLRA));
	
		!!Agricultural land demand by IMPLAN agricultural activities (LD submatrix):
		NSAM(MLRAZ,AGRZ)		= SUM((MLRA,AGR)$(SAM(MLRA,AGR)$(MAP(MLRA,MLRAZ)*MAP(AGR,AGRZ))),SAM(MLRA,AGR));

		!!Import duties paid by the commodity accounts (IMPTAX submatrix):
		NSAM(TAXZ,CZ)	= SUM((TAXK,CK)$(SAM(TAXK,CK)$(MAP(TAXK,TAXZ)*MAP(CK,CZ))),SAM(TAXK,CK));

		!!Transfers from the tax accounts to the government accounts (TAX submatrix):
		NSAM(IZ,TAXZ)	= SUM((IK,TAXK)$(SAM(IK,TAXK)$(MAP(IK,IZ)*MAP(TAXK,TAXZ))),SAM(IK,TAXK));
	
	!!Trade with the rest of the world for the regional and national models	
		!!Trans-shipments (TRNSHP submatrix):
		NSAM(TZ,TTZ)	= SUM((TK,TTK)$(SAM(TK,TTK)$(MAP(TK,TZ)*MAP(TTK,TTZ))),SAM(TK,TTK));
	
		!!Commodity exports to the rest of the world (CEXPRT submatrix):
		NSAM(CZ,"RoW")	= SUM(CK$(SAM(CK,"25001")$(MAP(CK,CZ)*MAP("25001","RoW"))),SAM(CK,"25001"));
	
		!!Commodity imports from the rest of the world (CIMPRT submatrix):
		NSAM("RoW",CZ)	= SUM(CK$(SAM("25001",CK)$(MAP("25001","RoW")*MAP(CK,CZ))),SAM("25001",CK));
	
		!!Institutional transfers to the rest of the world (OUTTRNS submatrix):
		NSAM(IZ,"RoW")	= SUM(IK$(SAM(IK,"25001")$(MAP(IK,IZ)*MAP("25001","RoW"))),SAM(IK,"25001"));
	
		!!Institutional transfers from the rest of the world (INTRNS submatrix):
		NSAM("RoW",IZ)	= SUM(IK$(SAM("25001",IK)$(MAP("25001","RoW")*MAP(IK,IZ))),SAM("25001",IK));
	
		!!Factor exports to the rest of the world (FEXPRT submatrix):
		NSAM(FZ,"RoW")	= SUM(FK$(SAM(FK,"25001")$(MAP(FK,FZ)*MAP("25001","RoW"))),SAM(FK,"25001"));

		!!Factor imports from the rest of the world(FIMPRT submatrix):
		NSAM("RoW",FZ)	= SUM(FK$(SAM("25001",FK)$(MAP("25001","RoW")*MAP(FK,FZ))),SAM("25001",FK));
	
	!!Trade with the rest of the US for the regional model
		!!Commodity exports to the rest of the US (CEXPRT submatrix):
		NSAM(CZ,"RoUS")	= SUM(CK$(SAM(CK,"28001")$(MAP(CK,CZ)*MAP("28001","RoUS"))),SAM(CK,"28001"));
	
		!!Commodity imports from the rest of the US (CIMPRT submatrix):
		NSAM("RoUS",CZ)	= SUM(CK$(SAM("28001",CK)$(MAP("28001","RoUS")*MAP(CK,CZ))),SAM("28001",CK));
	
		!!Institutional transfers to the rest of the US (OUTTRNS submatrix):
		NSAM(IZ,"RoUS")	= SUM(IK$(SAM(IK,"28001")$(MAP(IK,IZ)*MAP("28001","RoUS"))),SAM(IK,"28001"));
	
		!!Institutional transfers from the rest of the US (INTRNS submatrix):
		NSAM("RoUS",IZ)	= SUM(IK$(SAM("28001",IK)$(MAP("28001","RoUS")*MAP(IK,IZ))),SAM("28001",IK));
	
		!!Factor exports to the rest of the US (FEXPRT submatrix):
		NSAM(FZ,"RoUS")	= SUM(FK$(SAM(FK,"28001")$(MAP(FK,FZ)*MAP("28001","RoUS"))),SAM(FK,"28001"));

		!!Factor imports from the rest of the US(FIMPRT submatrix):
		NSAM("RoUS",FZ)	= SUM(FK$(SAM("28001",FK)$(MAP("28001","RoUS")*MAP(FK,FZ))),SAM("28001",FK));
	
		!!Employment data from IMPLAN:
		LABOR(AZ)	= SUM((AK)$(EMPLOY('20001',AK)$(MAP(AK,AZ))),EMPLOY('20001',AK));
		
	!!Acreage data by MLRA and agricultural activity in millions of acres from LAND.gdx:
		ACREAGE(MLRAZ,AGRZ) = SUM((MLRA,AGR)$(ACRESAGG(MLRA,AGR)$(MAP(MLRA,MLRAZ)*MAP(AGR,AGRZ))),ACRESAGG(MLRA,AGR));

	!!Rents per acre data by aggregated agricultural activity in $/acre:
		ACRERENT(MLRAZ,AGRZ) = SUM((MLRA,AGR)$(RENTACRE(MLRA,AGR)$(MAP(MLRA,MLRAZ)*MAP(AGR,AGRZ))),RENTACRE(MLRA,AGR));

!!SAM BALANCING AND ADJUSTMENT
	!!These are parameters I created that will be useful to check if the SAM is balanced and will be
    !!included in the GMS file. When executing this file these parameters will be shown in 
    !!the DISPLAY section of the LIST file. 
    	PARAMETER
    		DIFF(Z)		Differences between column and row sums,
    		SAM_CHK		Difference between the sum of row and column sums,
    		DIFF_CHK	Summation of the absolute values of differences between column and row sums. The closer to zero the better
			;
    	
    !!Creating the values that will fill the TOTAL and DIFF rows and colmuns of the extended SAM
    	NSAM(Z,"TOTAL") = 0;
    	NSAM(Z,"TOTAL") = NSAM(Z,"TOTAL") + SUM(ZZ,NSAM(Z,ZZ));
    	NSAM("TOTAL",Z) = 0;
    	NSAM("TOTAL",Z) = NSAM("TOTAL",Z) + SUM(ZZ,NSAM(ZZ,Z));
    	NSAM("DIFF",Z) = 0;
    	NSAM("DIFF",Z) = NSAM("TOTAL",Z) - NSAM(Z,"TOTAL");
    	DIFF(Z)		= NSAM("DIFF",Z);
    	DIFF_CHK	= SUM(Z,ABS(DIFF(Z)));
    	SAM_CHK		= SUM(Z,NSAM("TOTAL",Z))-SUM(Z,NSAM(Z,"TOTAL"));
    	DISPLAY REGION,DIFF_CHK, SAM_CHK, DIFF;

!!EXPORTING THE SAM
    !!This is the EXECUTE command to create the GDX file
    EXECUTE_UNLOAD "dsam.gdx",NSAM,AZ,AGRZ,CZ,FZ,IZ,TZ,MLRAZ,TAXZ,REGION,AGG,ACREAGE,ACRERENT,WOOD,AFF,WOODACREAGG,COSTREGION,CARBONREGION,DIFF_CHK,SAM_CHK;
*/
